@@ -877,6 +877,52 @@ class IotvideoClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeCloudStorageMultiThumbnail(self, request):
+        """拉取多个云存事件缩略图
+
+        :param request: Request instance for DescribeCloudStorageMultiThumbnail.
+        :type request: :class:`tencentcloud.iotvideo.v20211125.models.DescribeCloudStorageMultiThumbnailRequest`
+        :rtype: :class:`tencentcloud.iotvideo.v20211125.models.DescribeCloudStorageMultiThumbnailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeCloudStorageMultiThumbnail", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeCloudStorageMultiThumbnailResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeCloudStorageOrder(self, request):
+        """查询云存服务详情
+
+        :param request: Request instance for DescribeCloudStorageOrder.
+        :type request: :class:`tencentcloud.iotvideo.v20211125.models.DescribeCloudStorageOrderRequest`
+        :rtype: :class:`tencentcloud.iotvideo.v20211125.models.DescribeCloudStorageOrderResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeCloudStorageOrder", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeCloudStorageOrderResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeCloudStoragePackageConsumeDetails(self, request):
         """获取云存套餐包消耗详细记录
 
@@ -969,6 +1015,29 @@ class IotvideoClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeCloudStorageThumbnailList(self, request):
+        """批量拉取云存事件缩略图
+
+        :param request: Request instance for DescribeCloudStorageThumbnailList.
+        :type request: :class:`tencentcloud.iotvideo.v20211125.models.DescribeCloudStorageThumbnailListRequest`
+        :rtype: :class:`tencentcloud.iotvideo.v20211125.models.DescribeCloudStorageThumbnailListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeCloudStorageThumbnailList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeCloudStorageThumbnailListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeCloudStorageTime(self, request):
         """获取某一天云存时间轴
 
@@ -2119,6 +2188,29 @@ class IotvideoClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ResetCloudStorageEvent(self, request):
+        """重置云存事件
+
+        :param request: Request instance for ResetCloudStorageEvent.
+        :type request: :class:`tencentcloud.iotvideo.v20211125.models.ResetCloudStorageEventRequest`
+        :rtype: :class:`tencentcloud.iotvideo.v20211125.models.ResetCloudStorageEventResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ResetCloudStorageEvent", params, headers=headers)
+            response = json.loads(body)
+            model = models.ResetCloudStorageEventResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def RetryDeviceFirmwareTask(self, request):
         """本接口用于重试设备升级任务
 
